@@ -200,7 +200,7 @@ def setup(hub, raw_cli: Dict[str, Any]) -> Dict[str, Any]:
                     for named, sparse in hub.config.ARGS["subs"].items():
                         sparse.add_argument(*args, **kwargs)
                     continue
-                sparse = hub.config.ARGS["subs"].get(sub)
+                sparse = hub.config.ARGS.get("subs", {}).get(sub)
                 if not sparse:
                     # Maybe raise exception here? Malformed config?
                     continue
